{% extends "rest_framework/base.html" %}
{% load staticfiles %}
{% load rest_framework %}
{% load pages_tags mezzanine_tags i18n %}
{% load mezzanine_api %}


{% block title %}
{% if name %}{{ name }} – {% endif %}
Mezzanine API
{% endblock %}


{% block style %}
    {% compress css %}
        {% block bootstrap_theme %}
            <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/bootstrap.min.css" %}"/>
            <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/bootstrap-tweaks.css" %}"/>
        {% endblock %}
        <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/prettify.css" %}"/>
        <link rel="stylesheet" type="text/css" href="{% static "rest_framework/css/default.css" %}"/>
        <link rel="stylesheet" type="text/css" href="{% static "mezzanine_api/css/default.css" %}"/>
    {% endcompress %}
{% endblock %}


{% block navbar %}
    <div class="navbar navbar-static-top {% block bootstrap_navbar_variant %}navbar-inverse{% endblock %}">
        <div class="container">
            <span>
                {% block branding %}
                    <a class='navbar-brand' rel="nofollow" href='http://gcushen.github.io/mezzanine-api' target="_blank">
                        <img src="{% static "mezzanine_api/img/mezzanine_api_logo.png" %}"/>
                        Mezzanine API <span class="version">{% get_mezzanine_api_version %}</span>
                    </a>
                {% endblock %}
            </span>
            <ul class="nav navbar-nav pull-right">
                {% block userlinks %}
                    {% if user.is_authenticated %}
                        {% optional_logout request user %}
                    {% else %}
                        {% optional_login request %}
                    {% endif %}
                {% endblock %}
            </ul>
        </div>
    </div>
{% endblock %}
