{% extends "rest_framework/login_base.html" %}

{% block title %}{% if name %}{{ name }} – {% endif %}Mezzanine API{% endblock %}
{% block branding %}<h3 style="margin: 0 0 20px 0;">Mezzanine API</h3>{% endblock %}
